You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by er...@apache.org on 2012/02/14 17:18:50 UTC

svn commit: r1244107 [7/18] - in /commons/proper/math/trunk: ./ src/main/java/org/apache/commons/math/ src/main/java/org/apache/commons/math3/ src/main/java/org/apache/commons/math3/analysis/ src/main/java/org/apache/commons/math3/analysis/function/ sr...

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/DefaultRealMatrixChangingVisitor.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/DefaultRealMatrixChangingVisitor.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/DefaultRealMatrixChangingVisitor.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/DefaultRealMatrixChangingVisitor.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 /**
  * Default implementation of the {@link RealMatrixChangingVisitor} interface.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/DefaultRealMatrixPreservingVisitor.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/DefaultRealMatrixPreservingVisitor.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/DefaultRealMatrixPreservingVisitor.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/DefaultRealMatrixPreservingVisitor.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 /**
  * Default implementation of the {@link RealMatrixPreservingVisitor} interface.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/EigenDecomposition.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/EigenDecomposition.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/EigenDecomposition.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/EigenDecomposition.java Tue Feb 14 16:17:55 2012
@@ -15,13 +15,13 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.exception.MaxCountExceededException;
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.Precision;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.MaxCountExceededException;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.Precision;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Calculates the eigen decomposition of a real <strong>symmetric</strong>

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/FieldDecompositionSolver.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/FieldDecompositionSolver.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/FieldDecompositionSolver.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/FieldDecompositionSolver.java Tue Feb 14 16:17:55 2012
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.FieldElement;
+import org.apache.commons.math3.FieldElement;
 
 
 /**
@@ -42,7 +42,7 @@ public interface FieldDecompositionSolve
      * decomposition algorithm.</p>
      * @param b right-hand side of the equation A &times; X = B
      * @return a vector X that minimizes the two norm of A &times; X - B
-     * @throws org.apache.commons.math.exception.DimensionMismatchException
+     * @throws org.apache.commons.math3.exception.DimensionMismatchException
      * if the matrices dimensions do not match.
      * @throws SingularMatrixException
      * if the decomposed matrix is singular.
@@ -54,7 +54,7 @@ public interface FieldDecompositionSolve
      * decomposition algorithm.</p>
      * @param b right-hand side of the equation A &times; X = B
      * @return a matrix X that minimizes the two norm of A &times; X - B
-     * @throws org.apache.commons.math.exception.DimensionMismatchException
+     * @throws org.apache.commons.math3.exception.DimensionMismatchException
      * if the matrices dimensions do not match.
      * @throws SingularMatrixException
      * if the decomposed matrix is singular.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/FieldLUDecomposition.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/FieldLUDecomposition.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/FieldLUDecomposition.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/FieldLUDecomposition.java Tue Feb 14 16:17:55 2012
@@ -15,13 +15,13 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 import java.lang.reflect.Array;
 
-import org.apache.commons.math.Field;
-import org.apache.commons.math.FieldElement;
-import org.apache.commons.math.exception.DimensionMismatchException;
+import org.apache.commons.math3.Field;
+import org.apache.commons.math3.FieldElement;
+import org.apache.commons.math3.exception.DimensionMismatchException;
 
 /**
  * Calculates the LUP-decomposition of a square matrix.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/FieldMatrix.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/FieldMatrix.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/FieldMatrixChangingVisitor.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/FieldMatrixChangingVisitor.java Tue Feb 14 16:17:55 2012
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.FieldElement;
+import org.apache.commons.math3.FieldElement;
 
 /**
  * Interface defining a visitor for matrix entries.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/FieldMatrixPreservingVisitor.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/FieldMatrixPreservingVisitor.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/FieldMatrixPreservingVisitor.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/FieldMatrixPreservingVisitor.java Tue Feb 14 16:17:55 2012
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.FieldElement;
+import org.apache.commons.math3.FieldElement;
 
 /**
  * Interface defining a visitor for matrix entries.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/FieldVector.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/FieldVector.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/IllConditionedOperatorException.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/IllConditionedOperatorException.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /**
  * An exception to be thrown when the condition number of a

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/IterativeLinearSolver.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/IterativeLinearSolver.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/IterativeLinearSolver.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/IterativeLinearSolver.java Tue Feb 14 16:17:55 2012
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.MaxCountExceededException;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.util.IterationManager;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.MaxCountExceededException;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.util.IterationManager;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * This abstract class defines an iterative solver for the linear system A
@@ -114,7 +114,7 @@ public abstract class IterativeLinearSol
      * inconsistent with {@code a}
      * @throws MaxCountExceededException at exhaustion of the iteration count,
      * unless a custom
-     * {@link org.apache.commons.math.util.Incrementor.MaxCountExceededCallback callback}
+     * {@link org.apache.commons.math3.util.Incrementor.MaxCountExceededCallback callback}
      * has been set at construction
      */
     public RealVector solve(final RealLinearOperator a, final RealVector b)
@@ -140,7 +140,7 @@ public abstract class IterativeLinearSol
      * dimensions inconsistent with {@code a}
      * @throws MaxCountExceededException at exhaustion of the iteration count,
      * unless a custom
-     * {@link org.apache.commons.math.util.Incrementor.MaxCountExceededCallback callback}
+     * {@link org.apache.commons.math3.util.Incrementor.MaxCountExceededCallback callback}
      * has been set at construction
      */
     public RealVector solve(RealLinearOperator a, RealVector b, RealVector x0)
@@ -165,7 +165,7 @@ public abstract class IterativeLinearSol
      * dimensions inconsistent with {@code a}
      * @throws MaxCountExceededException at exhaustion of the iteration count,
      * unless a custom
-     * {@link org.apache.commons.math.util.Incrementor.MaxCountExceededCallback callback}
+     * {@link org.apache.commons.math3.util.Incrementor.MaxCountExceededCallback callback}
      * has been set at construction
      */
     public abstract RealVector solveInPlace(RealLinearOperator a, RealVector b,

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/IterativeLinearSolverEvent.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/IterativeLinearSolverEvent.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/IterativeLinearSolverEvent.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/IterativeLinearSolverEvent.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.util.IterationEvent;
-import org.apache.commons.math.exception.MathUnsupportedOperationException;
+import org.apache.commons.math3.util.IterationEvent;
+import org.apache.commons.math3.exception.MathUnsupportedOperationException;
 
 /**
  * This is the base class for all events occuring during the iterations of a

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/JacobiPreconditioner.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/JacobiPreconditioner.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/JacobiPreconditioner.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/JacobiPreconditioner.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 /**
  * This class implements the standard Jacobi (diagonal) preconditioner. For a

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/LUDecomposition.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/LUDecomposition.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/LUDecomposition.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/LUDecomposition.java Tue Feb 14 16:17:55 2012
@@ -15,10 +15,10 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Calculates the LUP-decomposition of a square matrix.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/MatrixDimensionMismatchException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/MatrixDimensionMismatchException.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/MatrixDimensionMismatchException.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/MatrixDimensionMismatchException.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.exception.MultiDimensionMismatchException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.MultiDimensionMismatchException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /**
  * Exception to be thrown when either the number of rows or the number of

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/MatrixUtils.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/MatrixUtils.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/MatrixUtils.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/MatrixUtils.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 import java.io.IOException;
 import java.io.ObjectInputStream;
@@ -23,21 +23,21 @@ import java.io.ObjectOutputStream;
 import java.lang.reflect.Array;
 import java.util.Arrays;
 
-import org.apache.commons.math.Field;
-import org.apache.commons.math.FieldElement;
-import org.apache.commons.math.exception.MathArithmeticException;
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.OutOfRangeException;
-import org.apache.commons.math.exception.NoDataException;
-import org.apache.commons.math.exception.NumberIsTooSmallException;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.ZeroException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.fraction.BigFraction;
-import org.apache.commons.math.fraction.Fraction;
-import org.apache.commons.math.util.FastMath;
-import org.apache.commons.math.util.Precision;
+import org.apache.commons.math3.Field;
+import org.apache.commons.math3.FieldElement;
+import org.apache.commons.math3.exception.MathArithmeticException;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.OutOfRangeException;
+import org.apache.commons.math3.exception.NoDataException;
+import org.apache.commons.math3.exception.NumberIsTooSmallException;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.ZeroException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.fraction.BigFraction;
+import org.apache.commons.math3.fraction.Fraction;
+import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math3.util.Precision;
 
 /**
  * A collection of static methods that operate on or return matrices.
@@ -105,7 +105,7 @@ public class MatrixUtils {
      *
      * @param data input array
      * @return  RealMatrix containing the values of the array
-     * @throws org.apache.commons.math.exception.DimensionMismatchException
+     * @throws org.apache.commons.math3.exception.DimensionMismatchException
      * if {@code data} is not rectangular (not all rows have the same length).
      * @throws NoDataException if a row or column is empty.
      * @throws NullArgumentException if either {@code data} or {@code data[0]}
@@ -132,7 +132,7 @@ public class MatrixUtils {
      * @param <T> the type of the field elements
      * @param data input array
      * @return a matrix containing the values of the array.
-     * @throws org.apache.commons.math.exception.DimensionMismatchException
+     * @throws org.apache.commons.math3.exception.DimensionMismatchException
      * if {@code data} is not rectangular (not all rows have the same length).
      * @throws NoDataException if a row or column is empty.
      * @throws NullArgumentException if either {@code data} or {@code data[0]}

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/NonPositiveDefiniteMatrixException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/NonPositiveDefiniteMatrixException.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/NonPositiveDefiniteMatrixException.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/NonPositiveDefiniteMatrixException.java Tue Feb 14 16:17:55 2012
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.exception.NumberIsTooSmallException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.exception.util.ExceptionContext;
+import org.apache.commons.math3.exception.NumberIsTooSmallException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.util.ExceptionContext;
 
 /**
  * Exception to be thrown when a positive definite matrix is expected.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/NonPositiveDefiniteOperatorException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/NonPositiveDefiniteOperatorException.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/NonPositiveDefiniteOperatorException.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/NonPositiveDefiniteOperatorException.java Tue Feb 14 16:17:55 2012
@@ -15,10 +15,10 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /**
  * Exception to be thrown when a symmetric, definite positive

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/NonSelfAdjointOperatorException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/NonSelfAdjointOperatorException.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/NonSelfAdjointOperatorException.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/NonSelfAdjointOperatorException.java Tue Feb 14 16:17:55 2012
@@ -15,10 +15,10 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /**
  * Exception to be thrown when a self-adjoint {@link RealLinearOperator}

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/NonSquareMatrixException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/NonSquareMatrixException.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/NonSquareMatrixException.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/NonSquareMatrixException.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /**
  * Exception to be thrown when a square matrix is expected.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/NonSquareOperatorException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/NonSquareOperatorException.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/NonSquareOperatorException.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/NonSquareOperatorException.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /**
  * Exception to be thrown when a square linear operator is expected.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/NonSymmetricMatrixException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/NonSymmetricMatrixException.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/NonSymmetricMatrixException.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/NonSymmetricMatrixException.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /**
  * Exception to be thrown when a symmetric matrix is expected.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/OpenMapRealMatrix.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/OpenMapRealMatrix.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/OpenMapRealMatrix.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/OpenMapRealMatrix.java Tue Feb 14 16:17:55 2012
@@ -15,12 +15,12 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.exception.NumberIsTooLargeException;
-import org.apache.commons.math.util.OpenIntToDoubleHashMap;
+import org.apache.commons.math3.exception.NumberIsTooLargeException;
+import org.apache.commons.math3.util.OpenIntToDoubleHashMap;
 
 /**
  * Sparse matrix implementation based on an open addressed map.
@@ -91,7 +91,7 @@ public class OpenMapRealMatrix extends A
      *
      * @param m Matrix to be added.
      * @return {@code this} + {@code m}.
-     * @throws org.apache.commons.math.exception.DimensionMismatchException
+     * @throws org.apache.commons.math3.exception.DimensionMismatchException
      * if {@code m} is not the same size as this matrix.
      */
     public OpenMapRealMatrix add(OpenMapRealMatrix m) {
@@ -126,7 +126,7 @@ public class OpenMapRealMatrix extends A
      *
      * @param m Matrix to be subtracted.
      * @return {@code this} - {@code m}.
-     * @throws org.apache.commons.math.exception.DimensionMismatchException
+     * @throws org.apache.commons.math3.exception.DimensionMismatchException
      * if {@code m} is not the same size as this matrix.
      */
     public OpenMapRealMatrix subtract(OpenMapRealMatrix m) {

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/OpenMapRealVector.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/OpenMapRealVector.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/OpenMapRealVector.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/OpenMapRealVector.java Tue Feb 14 16:17:55 2012
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.exception.MathArithmeticException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.OpenIntToDoubleHashMap;
-import org.apache.commons.math.util.OpenIntToDoubleHashMap.Iterator;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.MathArithmeticException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.OpenIntToDoubleHashMap;
+import org.apache.commons.math3.util.OpenIntToDoubleHashMap.Iterator;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * This class implements the {@link RealVector} interface with a
@@ -236,7 +236,7 @@ public class OpenMapRealVector extends S
      *
      * @param v Vector to add.
      * @return the sum of {@code this} and {@code v}.
-     * @throws org.apache.commons.math.exception.DimensionMismatchException
+     * @throws org.apache.commons.math3.exception.DimensionMismatchException
      * if the dimensions do not match.
      */
     public OpenMapRealVector add(OpenMapRealVector v) {
@@ -309,7 +309,7 @@ public class OpenMapRealVector extends S
      *
      * @param v Cector to compute the dot product with.
      * @return the dot product of {@code this} and {@code v}.
-     * @throws org.apache.commons.math.exception.DimensionMismatchException
+     * @throws org.apache.commons.math3.exception.DimensionMismatchException
      * if the dimensions do not match.
      */
     public double dotProduct(OpenMapRealVector v) {
@@ -390,7 +390,7 @@ public class OpenMapRealVector extends S
      *
      * @param v Vector to compute distance to.
      * @return the distance from {@code this} and {@code v}.
-     * @throws org.apache.commons.math.exception.DimensionMismatchException
+     * @throws org.apache.commons.math3.exception.DimensionMismatchException
      * if the dimensions do not match.
      */
     public double getDistance(OpenMapRealVector v) {
@@ -600,7 +600,7 @@ public class OpenMapRealVector extends S
      *
      * @param v Vector to subtract from {@code this}.
      * @return the difference of {@code this} and {@code v}.
-     * @throws org.apache.commons.math.exception.DimensionMismatchException
+     * @throws org.apache.commons.math3.exception.DimensionMismatchException
      * if the dimensions do not match.
      */
     public OpenMapRealVector subtract(OpenMapRealVector v) {

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/PivotingQRDecomposition.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/PivotingQRDecomposition.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/PivotingQRDecomposition.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/PivotingQRDecomposition.java Tue Feb 14 16:17:55 2012
@@ -13,14 +13,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 import java.util.Arrays;
-import org.apache.commons.math.util.MathArrays;
-import org.apache.commons.math.exception.ConvergenceException;
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.util.MathArrays;
+import org.apache.commons.math3.exception.ConvergenceException;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  *

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/PreconditionedIterativeLinearSolver.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/PreconditionedIterativeLinearSolver.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/PreconditionedIterativeLinearSolver.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/PreconditionedIterativeLinearSolver.java Tue Feb 14 16:17:55 2012
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.MaxCountExceededException;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.util.IterationManager;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.MaxCountExceededException;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.util.IterationManager;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * <p>
@@ -80,7 +80,7 @@ public abstract class PreconditionedIter
      * {@code x0} have dimensions inconsistent with {@code a}
      * @throws MaxCountExceededException at exhaustion of the iteration count,
      * unless a custom
-     * {@link org.apache.commons.math.util.Incrementor.MaxCountExceededCallback callback}
+     * {@link org.apache.commons.math3.util.Incrementor.MaxCountExceededCallback callback}
      * has been set at construction
      */
     public RealVector solve(final RealLinearOperator a,
@@ -163,7 +163,7 @@ public abstract class PreconditionedIter
      * dimensions inconsistent with {@code a}
      * @throws MaxCountExceededException at exhaustion of the iteration count,
      * unless a custom
-     * {@link org.apache.commons.math.util.Incrementor.MaxCountExceededCallback callback}
+     * {@link org.apache.commons.math3.util.Incrementor.MaxCountExceededCallback callback}
      * has been set at construction
      */
     public RealVector solve(RealLinearOperator a, RealLinearOperator minv,
@@ -192,7 +192,7 @@ public abstract class PreconditionedIter
      * {@code x0} have dimensions inconsistent with {@code a}
      * @throws MaxCountExceededException at exhaustion of the iteration count,
      * unless a custom
-     * {@link org.apache.commons.math.util.Incrementor.MaxCountExceededCallback callback}
+     * {@link org.apache.commons.math3.util.Incrementor.MaxCountExceededCallback callback}
      * has been set at construction.
      */
     public abstract RealVector solveInPlace(RealLinearOperator a,

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/QRDecomposition.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/QRDecomposition.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/QRDecomposition.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/QRDecomposition.java Tue Feb 14 16:17:55 2012
@@ -15,12 +15,12 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 import java.util.Arrays;
 
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.util.FastMath;
 
 
 /**

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RealLinearOperator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RealLinearOperator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RealLinearOperator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RealLinearOperator.java Tue Feb 14 16:17:55 2012
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.DimensionMismatchException;
 
 /**
  * This class defines a linear operator operating on real ({@code double})
@@ -70,7 +70,7 @@ public abstract class RealLinearOperator
      *
      * @param x the vector to operate on
      * @return the product of {@code this} instance with {@code x}
-     * @throws org.apache.commons.math.exception.DimensionMismatchException
+     * @throws org.apache.commons.math3.exception.DimensionMismatchException
      * if the column dimension does not match the size of {@code x}
      */
     public abstract RealVector operate(final RealVector x);
@@ -84,7 +84,7 @@ public abstract class RealLinearOperator
      * @param x the vector to operate on
      * @return the product of the transpose of {@code this} instance with
      * {@code x}
-     * @throws org.apache.commons.math.exception.DimensionMismatchException
+     * @throws org.apache.commons.math3.exception.DimensionMismatchException
      * if the row dimension does not match the size of {@code x}
      * @throws UnsupportedOperationException if this operation is not supported
      * by {@code this} operator

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RealMatrix.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RealMatrix.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RealMatrixChangingVisitor.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RealMatrixChangingVisitor.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 /**
  * Interface defining a visitor for matrix entries.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RealMatrixPreservingVisitor.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RealMatrixPreservingVisitor.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RealMatrixPreservingVisitor.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RealMatrixPreservingVisitor.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 /**
  * Interface defining a visitor for matrix entries.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RealVector.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RealVector.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RealVector.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RealVector.java Tue Feb 14 16:17:55 2012
@@ -15,22 +15,22 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 import java.util.Iterator;
 import java.util.NoSuchElementException;
 
-import org.apache.commons.math.exception.MathUnsupportedOperationException;
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.OutOfRangeException;
-import org.apache.commons.math.exception.MathArithmeticException;
-import org.apache.commons.math.analysis.FunctionUtils;
-import org.apache.commons.math.analysis.function.Add;
-import org.apache.commons.math.analysis.function.Multiply;
-import org.apache.commons.math.analysis.function.Divide;
-import org.apache.commons.math.analysis.UnivariateFunction;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.MathUnsupportedOperationException;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.OutOfRangeException;
+import org.apache.commons.math3.exception.MathArithmeticException;
+import org.apache.commons.math3.analysis.FunctionUtils;
+import org.apache.commons.math3.analysis.function.Add;
+import org.apache.commons.math3.analysis.function.Multiply;
+import org.apache.commons.math3.analysis.function.Divide;
+import org.apache.commons.math3.analysis.UnivariateFunction;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Class defining a real-valued vector with basic algebraic operations.
@@ -68,7 +68,7 @@ public abstract class RealVector {
      *
      * @param index Index location of entry to be fetched.
      * @return the vector entry at {@code index}.
-     * @throws org.apache.commons.math.exception.OutOfRangeException
+     * @throws org.apache.commons.math3.exception.OutOfRangeException
      * if the index is not valid.
      * @see #setEntry(int, double)
      */
@@ -79,7 +79,7 @@ public abstract class RealVector {
      *
      * @param index element index.
      * @param value new value for the element.
-     * @throws org.apache.commons.math.exception.OutOfRangeException
+     * @throws org.apache.commons.math3.exception.OutOfRangeException
      * if the index is not valid.
      * @see #getEntry(int)
      */
@@ -90,7 +90,7 @@ public abstract class RealVector {
      *
      * @param index Index location of entry to be set.
      * @param increment Value to add to the vector entry.
-     * @throws org.apache.commons.math.exception.OutOfRangeException if
+     * @throws org.apache.commons.math3.exception.OutOfRangeException if
      * the index is not valid.
      * @since 3.0
      */
@@ -120,7 +120,7 @@ public abstract class RealVector {
      * @param index index of first element.
      * @param n number of elements to be retrieved.
      * @return a vector containing n elements.
-     * @throws org.apache.commons.math.exception.OutOfRangeException
+     * @throws org.apache.commons.math3.exception.OutOfRangeException
      * if the index is not valid.
      */
     public abstract RealVector getSubVector(int index, int n);
@@ -130,7 +130,7 @@ public abstract class RealVector {
      *
      * @param index index of first element to be set.
      * @param v vector containing the values to set.
-     * @throws org.apache.commons.math.exception.OutOfRangeException
+     * @throws org.apache.commons.math3.exception.OutOfRangeException
      * if the index is not valid.
      */
     public abstract void setSubVector(int index, RealVector v);
@@ -196,7 +196,7 @@ public abstract class RealVector {
      *
      * @param v Vector to be added.
      * @return {@code this} + {@code v}.
-     * @throws org.apache.commons.math.exception.DimensionMismatchException
+     * @throws org.apache.commons.math3.exception.DimensionMismatchException
      * if {@code v} is not the same size as this vector.
      */
     public RealVector add(RealVector v) {
@@ -216,7 +216,7 @@ public abstract class RealVector {
      *
      * @param v Vector to be subtracted.
      * @return {@code this} - {@code v}.
-     * @throws org.apache.commons.math.exception.DimensionMismatchException
+     * @throws org.apache.commons.math3.exception.DimensionMismatchException
      * if {@code v} is not the same size as this vector.
      */
     public RealVector subtract(RealVector v) {
@@ -267,7 +267,7 @@ public abstract class RealVector {
      *
      * @param v Vector with which dot product should be computed
      * @return the scalar dot product between this instance and {@code v}.
-     * @throws org.apache.commons.math.exception.DimensionMismatchException
+     * @throws org.apache.commons.math3.exception.DimensionMismatchException
      * if {@code v} is not the same size as this vector.
      */
     public double dotProduct(RealVector v) {
@@ -304,7 +304,7 @@ public abstract class RealVector {
      *
      * @param v Vector by which instance elements must be divided.
      * @return a vector containing this[i] / v[i] for all i.
-     * @throws org.apache.commons.math.exception.DimensionMismatchException
+     * @throws org.apache.commons.math3.exception.DimensionMismatchException
      * if {@code v} is not the same size as this vector.
      */
     public abstract RealVector ebeDivide(RealVector v);
@@ -314,7 +314,7 @@ public abstract class RealVector {
      *
      * @param v Vector by which instance elements must be multiplied
      * @return a vector containing this[i] * v[i] for all i.
-     * @throws org.apache.commons.math.exception.DimensionMismatchException
+     * @throws org.apache.commons.math3.exception.DimensionMismatchException
      * if {@code v} is not the same size as this vector.
      */
     public abstract RealVector ebeMultiply(RealVector v);
@@ -327,7 +327,7 @@ public abstract class RealVector {
      *
      * @param v Vector to which distance is requested.
      * @return the distance between two vectors.
-     * @throws org.apache.commons.math.exception.DimensionMismatchException
+     * @throws org.apache.commons.math3.exception.DimensionMismatchException
      * if {@code v} is not the same size as this vector.
      * @see #getL1Distance(RealVector)
      * @see #getLInfDistance(RealVector)
@@ -414,7 +414,7 @@ public abstract class RealVector {
      *
      * @param v Vector to which distance is requested.
      * @return the distance between two vectors.
-     * @throws org.apache.commons.math.exception.DimensionMismatchException
+     * @throws org.apache.commons.math3.exception.DimensionMismatchException
      * if {@code v} is not the same size as this vector.
      */
     public double getL1Distance(RealVector v) {
@@ -436,7 +436,7 @@ public abstract class RealVector {
      *
      * @param v Vector to which distance is requested.
      * @return the distance between two vectors.
-     * @throws org.apache.commons.math.exception.DimensionMismatchException
+     * @throws org.apache.commons.math3.exception.DimensionMismatchException
      * if {@code v} is not the same size as this vector.
      * @see #getDistance(RealVector)
      * @see #getL1Distance(RealVector)
@@ -617,7 +617,7 @@ public abstract class RealVector {
      *
      * @param v vector onto which instance must be projected.
      * @return projection of the instance onto {@code v}.
-     * @throws org.apache.commons.math.exception.DimensionMismatchException
+     * @throws org.apache.commons.math3.exception.DimensionMismatchException
      * if {@code v} is not the same size as this vector.
      */
     public abstract RealVector projection(RealVector v);
@@ -668,7 +668,7 @@ public abstract class RealVector {
      * Converts this vector into a unit vector.
      * The instance itself is changed by this method.
      *
-     * @throws org.apache.commons.math.exception.MathArithmeticException
+     * @throws org.apache.commons.math3.exception.MathArithmeticException
      * if the norm is zero.
      */
     public void unitize() {
@@ -770,7 +770,7 @@ public abstract class RealVector {
      * @param y Vector with which {@code this} is linearly combined.
      * @return a vector containing {@code a * this[i] + b * y[i]} for all
      * {@code i}.
-     * @throws org.apache.commons.math.exception.DimensionMismatchException
+     * @throws org.apache.commons.math3.exception.DimensionMismatchException
      * if {@code y} is not the same size as this vector.
      */
     public RealVector combine(double a, double b, RealVector y) {
@@ -786,7 +786,7 @@ public abstract class RealVector {
      * @param y Vector with which {@code this} is linearly combined.
      * @return {@code this}, with components equal to
      * {@code a * this[i] + b * y[i]} for all {@code i}.
-     * @throws org.apache.commons.math.exception.DimensionMismatchException
+     * @throws org.apache.commons.math3.exception.DimensionMismatchException
      * if {@code y} is not the same size as this vector.
      */
     public RealVector combineToSelf(double a, double b, RealVector y) {

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RealVectorFormat.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RealVectorFormat.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RealVectorFormat.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RealVectorFormat.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 import java.text.FieldPosition;
 import java.text.NumberFormat;
@@ -24,8 +24,8 @@ import java.util.ArrayList;
 import java.util.List;
 import java.util.Locale;
 
-import org.apache.commons.math.exception.MathParseException;
-import org.apache.commons.math.util.CompositeFormat;
+import org.apache.commons.math3.exception.MathParseException;
+import org.apache.commons.math3.util.CompositeFormat;
 
 /**
  * Formats a vector in components list format "{v0; v1; ...; vk-1}".

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RectangularCholeskyDecomposition.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RectangularCholeskyDecomposition.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RectangularCholeskyDecomposition.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RectangularCholeskyDecomposition.java Tue Feb 14 16:17:55 2012
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Calculates the rectangular Cholesky decomposition of a matrix.
@@ -29,7 +29,7 @@ import org.apache.commons.math.util.Fast
  * is that rows/columns may be permuted (hence the rectangular shape instead
  * of the traditional triangular shape) and there is a threshold to ignore
  * small diagonal elements. This is used for example to generate {@link
- * org.apache.commons.math.random.CorrelatedRandomVectorGenerator correlated
+ * org.apache.commons.math3.random.CorrelatedRandomVectorGenerator correlated
  * random n-dimensions vectors} in a p-dimension subspace (p < n).
  * In other words, it allows generating random vectors from a covariance
  * matrix that is only positive semidefinite, and not positive definite.</p>

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SingularMatrixException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SingularMatrixException.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SingularMatrixException.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SingularMatrixException.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /**
  * Exception to be thrown when a non-singular matrix is expected.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SingularOperatorException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SingularOperatorException.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SingularOperatorException.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SingularOperatorException.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /**
  * Exception to be thrown when trying to invert a singular operator.
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/FieldMatrix.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/FieldMatrix.java Tue Feb 14 16:17:55 2012
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 
-import org.apache.commons.math.Field;
-import org.apache.commons.math.FieldElement;
+import org.apache.commons.math3.Field;
+import org.apache.commons.math3.FieldElement;
 
 /**
  * Interface defining field-valued matrix with basic algebraic operations.
@@ -45,7 +45,7 @@ public interface FieldMatrix<T extends F
      * @param rowDimension  the number of rows in the new matrix
      * @param columnDimension  the number of columns in the new matrix
      * @return a new matrix of the same type as the instance
-     * @throws org.apache.commons.math.exception.NotStrictlyPositiveException
+     * @throws org.apache.commons.math3.exception.NotStrictlyPositiveException
      * if row or column dimension is not positive.
      * @since 2.0
      */
@@ -109,7 +109,7 @@ public interface FieldMatrix<T extends F
      *
      * @param m Matrix to premultiply by.
      * @return {@code m} * {@code this}.
-     * @throws org.apache.commons.math.exception.DimensionMismatchException
+     * @throws org.apache.commons.math3.exception.DimensionMismatchException
      * if the number of columns of {@code m} differ from the number of rows
      * of this matrix.
      */
@@ -143,7 +143,7 @@ public interface FieldMatrix<T extends F
      * @param endColumn Final column index (inclusive)
      * @return the matrix containing the data of the
      * specified rows and columns.
-     * @throws org.apache.commons.math.exception.OutOfRangeException
+     * @throws org.apache.commons.math3.exception.OutOfRangeException
      * if the indices are not valid.
      */
    FieldMatrix<T> getSubMatrix(int startRow, int endRow, int startColumn, int endColumn);
@@ -156,7 +156,7 @@ public interface FieldMatrix<T extends F
     * @param selectedColumns Array of column indices.
     * @return the matrix containing the data in the
     * specified rows and columns.
-    * @throws org.apache.commons.math.exception.OutOfRangeException
+    * @throws org.apache.commons.math3.exception.OutOfRangeException
     * if row or column selections are not valid.
     */
    FieldMatrix<T> getSubMatrix(int[] selectedRows, int[] selectedColumns);
@@ -171,7 +171,7 @@ public interface FieldMatrix<T extends F
     * @param endColumn Final column index (inclusive).
     * @param destination The arrays where the submatrix data should be copied
     * (if larger than rows/columns counts, only the upper-left part will be used).
-    * @throws org.apache.commons.math.exception.OutOfRangeException
+    * @throws org.apache.commons.math3.exception.OutOfRangeException
     * if the indices are not valid.
     * @exception IllegalArgumentException if the destination array is too small.
     */
@@ -186,7 +186,7 @@ public interface FieldMatrix<T extends F
    * @param selectedColumns Array of column indices.
    * @param destination Arrays where the submatrix data should be copied
    * (if larger than rows/columns counts, only the upper-left part will be used)
-   * @throws org.apache.commons.math.exception.OutOfRangeException
+   * @throws org.apache.commons.math3.exception.OutOfRangeException
    * if the indices are not valid.
    * @exception IllegalArgumentException if the destination array is too small
    */
@@ -215,12 +215,12 @@ public interface FieldMatrix<T extends F
     * @throws MatrixDimensionMismatchException
     * if {@code subMatrix} does not fit into this matrix from element in
     * {@code (row, column)}.
     * @throws org.apache.commons.math.exception.ZeroException if a row or column
     * of {@code subMatrix} is empty.
-    * @throws org.apache.commons.math.exception.DimensionMismatchException
+    * @throws org.apache.commons.math3.exception.DimensionMismatchException
     * if {@code subMatrix} is not rectangular (not all rows have the same
     * length).
-    * @throws org.apache.commons.math.exception.NullArgumentException
+    * @throws org.apache.commons.math3.exception.NullArgumentException
     * if {@code subMatrix} is {@code null}.
     * @since 2.0
     */
@@ -232,7 +232,7 @@ public interface FieldMatrix<T extends F
     *
     * @param row Row to be fetched.
     * @return a row matrix.
-    * @throws org.apache.commons.math.exception.OutOfRangeException
+    * @throws org.apache.commons.math3.exception.OutOfRangeException
     * if the specified row index is invalid.
     */
    FieldMatrix<T> getRowMatrix(int row);
@@ -244,7 +244,7 @@ public interface FieldMatrix<T extends F
     * @param row Row to be set.
     * @param matrix Row matrix (must have one row and the same number
     * of columns as the instance).
-    * @throws org.apache.commons.math.exception.OutOfRangeException
+    * @throws org.apache.commons.math3.exception.OutOfRangeException
     * if the specified row index is invalid.
     * @throws MatrixDimensionMismatchException
     * if the matrix dimensions do not match one instance row.
@@ -257,7 +257,7 @@ public interface FieldMatrix<T extends F
     *
     * @param column Column to be fetched.
     * @return a column matrix.
-    * @throws org.apache.commons.math.exception.OutOfRangeException
+    * @throws org.apache.commons.math3.exception.OutOfRangeException
     * if the specified column index is invalid.
     */
    FieldMatrix<T> getColumnMatrix(int column);
@@ -269,7 +269,7 @@ public interface FieldMatrix<T extends F
     * @param column Column to be set.
     * @param matrix column matrix (must have one column and the same
     * number of rows as the instance).
-    * @throws org.apache.commons.math.exception.OutOfRangeException
+    * @throws org.apache.commons.math3.exception.OutOfRangeException
     * if the specified column index is invalid.
     * @throws MatrixDimensionMismatchException
     * if the matrix dimensions do not match one instance column.
@@ -282,7 +282,7 @@ public interface FieldMatrix<T extends F
     *
     * @param row Row to be fetched
     * @return a row vector.
-    * @throws org.apache.commons.math.exception.OutOfRangeException
+    * @throws org.apache.commons.math3.exception.OutOfRangeException
     * if the specified row index is invalid.
     */
    FieldVector<T> getRowVector(int row);
@@ -294,7 +294,7 @@ public interface FieldMatrix<T extends F
     * @param row Row to be set.
     * @param vector row vector (must have the same number of columns
     * as the instance).
-    * @throws org.apache.commons.math.exception.OutOfRangeException
+    * @throws org.apache.commons.math3.exception.OutOfRangeException
     * if the specified row index is invalid.
     * @throws MatrixDimensionMismatchException
     * if the vector dimension does not match one instance row.
@@ -307,7 +307,7 @@ public interface FieldMatrix<T extends F
     *
     * @param column Column to be fetched.
     * @return a column vector.
-    * @throws org.apache.commons.math.exception.OutOfRangeException
+    * @throws org.apache.commons.math3.exception.OutOfRangeException
     * if the specified column index is invalid.
     */
    FieldVector<T> getColumnVector(int column);
@@ -319,7 +319,7 @@ public interface FieldMatrix<T extends F
     * @param column Column to be set.
     * @param vector Column vector (must have the same number of rows
     * as the instance).
-    * @throws org.apache.commons.math.exception.OutOfRangeException
+    * @throws org.apache.commons.math3.exception.OutOfRangeException
     * if the specified column index is invalid.
     * @throws MatrixDimensionMismatchException
     * if the vector dimension does not match one instance column.
@@ -331,7 +331,7 @@ public interface FieldMatrix<T extends F
      *
      * @param row Row to be fetched.
      * @return array of entries in the row.
-     * @throws org.apache.commons.math.exception.OutOfRangeException
+     * @throws org.apache.commons.math3.exception.OutOfRangeException
      * if the specified row index is not valid.
      */
     T[] getRow(int row);
@@ -343,7 +343,7 @@ public interface FieldMatrix<T extends F
      * @param row Row to be set.
      * @param array Row matrix (must have the same number of columns as
      * the instance).
-     * @throws org.apache.commons.math.exception.OutOfRangeException
+     * @throws org.apache.commons.math3.exception.OutOfRangeException
      * if the specified row index is invalid.
      * @throws MatrixDimensionMismatchException
      * if the array size does not match one instance row.
@@ -355,7 +355,7 @@ public interface FieldMatrix<T extends F
      *
      * @param column the column to be fetched
      * @return array of entries in the column
-     * @throws org.apache.commons.math.exception.OutOfRangeException
+     * @throws org.apache.commons.math3.exception.OutOfRangeException
      * if the specified column index is not valid.
      */
     T[] getColumn(int column);
@@ -366,7 +366,7 @@ public interface FieldMatrix<T extends F
      *
      * @param column the column to be set
      * @param array column array (must have the same number of rows as the instance)
-     * @throws org.apache.commons.math.exception.OutOfRangeException
+     * @throws org.apache.commons.math3.exception.OutOfRangeException
      * if the specified column index is invalid.
      * @throws MatrixDimensionMismatchException
      * if the array size does not match one instance column.
@@ -379,7 +379,7 @@ public interface FieldMatrix<T extends F
      * @param row  row location of entry to be fetched
      * @param column  column location of entry to be fetched
      * @return matrix entry in row,column
-     * @throws org.apache.commons.math.exception.OutOfRangeException
+     * @throws org.apache.commons.math3.exception.OutOfRangeException
      * if the row or column index is not valid.
      */
     T getEntry(int row, int column);
@@ -390,7 +390,7 @@ public interface FieldMatrix<T extends F
      * @param row  row location of entry to be set
      * @param column  column location of entry to be set
      * @param value matrix entry to be set in row,column
-     * @throws org.apache.commons.math.exception.OutOfRangeException
+     * @throws org.apache.commons.math3.exception.OutOfRangeException
      * if the row or column index is not valid.
      * @since 2.0
      */
@@ -403,7 +403,7 @@ public interface FieldMatrix<T extends F
      * @param column Column location of entry to be set.
      * @param increment Value to add to the current matrix entry in
      * {@code (row, column)}.
-     * @throws org.apache.commons.math.exception.OutOfRangeException
+     * @throws org.apache.commons.math3.exception.OutOfRangeException
      * if the row or column index is not valid.
      * @since 2.0
      */
@@ -416,7 +416,7 @@ public interface FieldMatrix<T extends F
      * @param column Column location of entry to be set.
      * @param factor Multiplication factor for the current matrix entry
      * in {@code (row,column)}
-     * @throws org.apache.commons.math.exception.OutOfRangeException
+     * @throws org.apache.commons.math3.exception.OutOfRangeException
      * if the row or column index is not valid.
      * @since 2.0
      */
@@ -529,7 +529,7 @@ public interface FieldMatrix<T extends F
      * @param endRow Final row index (inclusive)
      * @param startColumn Initial column index
      * @param endColumn Final column index
-     * @throws org.apache.commons.math.exception.OutOfRangeException
+     * @throws org.apache.commons.math3.exception.OutOfRangeException
      * if the indices are not valid.
      * @see #walkInRowOrder(FieldMatrixChangingVisitor)
      * @see #walkInRowOrder(FieldMatrixPreservingVisitor)
@@ -558,7 +558,7 @@ public interface FieldMatrix<T extends F
      * @param endRow Final row index (inclusive)
      * @param startColumn Initial column index
      * @param endColumn Final column index
-     * @throws org.apache.commons.math.exception.OutOfRangeException
+     * @throws org.apache.commons.math3.exception.OutOfRangeException
      * if the indices are not valid.
      * @see #walkInRowOrder(FieldMatrixChangingVisitor)
      * @see #walkInRowOrder(FieldMatrixPreservingVisitor)
@@ -631,7 +631,7 @@ public interface FieldMatrix<T extends F
      * @param endRow Final row index (inclusive)
      * @param startColumn Initial column index
      * @param endColumn Final column index
-     * @throws org.apache.commons.math.exception.OutOfRangeException
+     * @throws org.apache.commons.math3.exception.OutOfRangeException
      * if the indices are not valid.
      * @see #walkInRowOrder(FieldMatrixChangingVisitor)
      * @see #walkInRowOrder(FieldMatrixPreservingVisitor)
@@ -660,7 +660,7 @@ public interface FieldMatrix<T extends F
      * @param endRow Final row index (inclusive)
      * @param startColumn Initial column index
      * @param endColumn Final column index
-     * @throws org.apache.commons.math.exception.OutOfRangeException
+     * @throws org.apache.commons.math3.exception.OutOfRangeException
      * if the indices are not valid.
      * @see #walkInRowOrder(FieldMatrixChangingVisitor)
      * @see #walkInRowOrder(FieldMatrixPreservingVisitor)
@@ -730,7 +730,7 @@ public interface FieldMatrix<T extends F
      * @param endRow Final row index (inclusive)
      * @param startColumn Initial column index
      * @param endColumn Final column index (inclusive)
-     * @throws org.apache.commons.math.exception.OutOfRangeException
+     * @throws org.apache.commons.math3.exception.OutOfRangeException
      * if the indices are not valid.
      * @see #walkInRowOrder(FieldMatrixChangingVisitor)
      * @see #walkInRowOrder(FieldMatrixPreservingVisitor)
@@ -758,7 +758,7 @@ public interface FieldMatrix<T extends F
      * @param endRow Final row index (inclusive)
      * @param startColumn Initial column index
      * @param endColumn Final column index (inclusive)
-     * @throws org.apache.commons.math.exception.OutOfRangeException
+     * @throws org.apache.commons.math3.exception.OutOfRangeException
      * if the indices are not valid.
      * @see #walkInRowOrder(FieldMatrixChangingVisitor)
      * @see #walkInRowOrder(FieldMatrixPreservingVisitor)
@@ -215,12 +215,12 @@ public interface FieldMatrix<T extends F
     * if {@code subMatrix} does not fit into this matrix from element in
     * {@code (row, column)}.
-    * @throws org.apache.commons.math.exception.ZeroException if a row or column
+    * @throws org.apache.commons.math3.exception.ZeroException if a row or column
     * of {@code subMatrix} is empty.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/FieldMatrixChangingVisitor.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/FieldMatrixChangingVisitor.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/FieldVector.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/FieldVector.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.Field;
-import org.apache.commons.math.FieldElement;
+import org.apache.commons.math3.Field;
+import org.apache.commons.math3.FieldElement;
 
 /**
  * Interface defining a field-valued vector with basic algebraic operations.
@@ -199,7 +199,7 @@ public interface FieldVector<T extends F
      *
      * @param index Index location of entry to be fetched.
      * @return the vector entry at {@code index}.
      * @throws org.apache.commons.math.exception.OutOfRangeException if the
      * index is not valid.
      * @see #setEntry(int, FieldElement)
      */
@@ -209,7 +209,7 @@ public interface FieldVector<T extends F
      * Set a single element.
      * @param index element index.
      * @param value new value for the element.
-     * @throws org.apache.commons.math.exception.OutOfRangeException
+     * @throws org.apache.commons.math3.exception.OutOfRangeException
      * if the index is inconsistent with vector size.
      * @see #getEntry(int)
      */
@@ -240,7 +240,7 @@ public interface FieldVector<T extends F
      * @param index index of first element.
      * @param n number of elements to be retrieved.
      * @return a vector containing n elements.
-     * @throws org.apache.commons.math.exception.OutOfRangeException
+     * @throws org.apache.commons.math3.exception.OutOfRangeException
      * if the index is inconsistent with vector size.
      */
     FieldVector<T> getSubVector(int index, int n);
@@ -249,7 +249,7 @@ public interface FieldVector<T extends F
      * Set a set of consecutive elements.
      * @param index index of first element to be set.
      * @param v vector containing the values to set.
-     * @throws org.apache.commons.math.exception.OutOfRangeException
+     * @throws org.apache.commons.math3.exception.OutOfRangeException
      * if the index is inconsistent with vector size.
      */
     void setSubVector(int index, FieldVector<T> v);
@@ -199,7 +199,7 @@ public interface FieldVector<T extends F
      * @param index Index location of entry to be fetched.
      * @return the vector entry at {@code index}.
-     * @throws org.apache.commons.math.exception.OutOfRangeException if the
+     * @throws org.apache.commons.math3.exception.OutOfRangeException if the
      * index is not valid.
      * @see #setEntry(int, FieldElement)

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/IllConditionedOperatorException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/IllConditionedOperatorException.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RealMatrix.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RealMatrix.java Tue Feb 14 16:17:55 2012
@@ -15,12 +15,12 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.OutOfRangeException;
-import org.apache.commons.math.exception.ZeroException;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.OutOfRangeException;
+import org.apache.commons.math3.exception.ZeroException;
 
 /**
  * Interface defining a real-valued matrix with basic algebraic operations.
@@ -38,7 +38,7 @@ public interface RealMatrix extends AnyM
      * @param rowDimension  the number of rows in the new matrix
      * @param columnDimension  the number of columns in the new matrix
      * @return a new matrix of the same type as the instance
-     * @throws org.apache.commons.math.exception.NotStrictlyPositiveException
+     * @throws org.apache.commons.math3.exception.NotStrictlyPositiveException
      * if row or column dimension is not positive.
      * @since 2.0
      */
@@ -147,7 +147,7 @@ public interface RealMatrix extends AnyM
      * @param endColumn Final column index (inclusive)
      * @return The subMatrix containing the data of the
      *         specified rows and columns
-     * @throws org.apache.commons.math.exception.OutOfRangeException if
+     * @throws org.apache.commons.math3.exception.OutOfRangeException if
      * the indices are not valid.
      */
     RealMatrix getSubMatrix(int startRow, int endRow, int startColumn, int endColumn);
@@ -160,7 +160,7 @@ public interface RealMatrix extends AnyM
     * @param selectedColumns Array of column indices.
     * @return The subMatrix containing the data in the
     *         specified rows and columns
-    * @throws org.apache.commons.math.exception.OutOfRangeException if
+    * @throws org.apache.commons.math3.exception.OutOfRangeException if
     * the indices are not valid.
     */
     RealMatrix getSubMatrix(int[] selectedRows, int[] selectedColumns);
@@ -175,7 +175,7 @@ public interface RealMatrix extends AnyM
     * @param endColumn Final column index (inclusive)
     * @param destination The arrays where the submatrix data should be copied
     * (if larger than rows/columns counts, only the upper-left part will be used)
     * @throws org.apache.commons.math.exception.OutOfRangeException if the
     * indices are not valid.
     * @exception IllegalArgumentException if the destination array is too small
     */
@@ -189,7 +189,7 @@ public interface RealMatrix extends AnyM
      * @param selectedColumns Array of column indices.
      * @param destination The arrays where the submatrix data should be copied
      * (if larger than rows/columns counts, only the upper-left part will be used)
      * @throws org.apache.commons.math.exception.OutOfRangeException if the
      * indices are not valid.
      * @exception IllegalArgumentException if the destination array is too small
      */
@@ -232,7 +232,7 @@ public interface RealMatrix extends AnyM
     *
     * @param row Row to be fetched.
     * @return row Matrix.
-    * @throws org.apache.commons.math.exception.OutOfRangeException if
+    * @throws org.apache.commons.math3.exception.OutOfRangeException if
     * the specified row index is invalid.
     */
    RealMatrix getRowMatrix(int row);
@@ -244,7 +244,7 @@ public interface RealMatrix extends AnyM
     * @param row Row to be set.
     * @param matrix Row matrix (must have one row and the same number of
     * columns as the instance).
     * @throws org.apache.commons.math.exception.OutOfRangeException if the
     * specified row index is invalid.
     * @throws MatrixDimensionMismatchException
     * if the matrix dimensions do not match one instance row.
@@ -257,7 +257,7 @@ public interface RealMatrix extends AnyM
     *
     * @param column Column to be fetched.
     * @return column Matrix.
-    * @throws org.apache.commons.math.exception.OutOfRangeException if
+    * @throws org.apache.commons.math3.exception.OutOfRangeException if
     * the specified column index is invalid.
     */
    RealMatrix getColumnMatrix(int column);
@@ -269,7 +269,7 @@ public interface RealMatrix extends AnyM
     * @param column Column to be set.
     * @param matrix Column matrix (must have one column and the same number
     * of rows as the instance).
-    * @throws org.apache.commons.math.exception.OutOfRangeException if
+    * @throws org.apache.commons.math3.exception.OutOfRangeException if
     * the specified column index is invalid.
     * @throws MatrixDimensionMismatchException
     * if the {@code matrix} dimensions do not match one instance column.
@@ -282,7 +282,7 @@ public interface RealMatrix extends AnyM
     *
     * @param row Row to be fetched.
     * @return a row vector.
-    * @throws org.apache.commons.math.exception.OutOfRangeException if
+    * @throws org.apache.commons.math3.exception.OutOfRangeException if
     * the specified row index is invalid.
     */
    RealVector getRowVector(int row);
@@ -294,7 +294,7 @@ public interface RealMatrix extends AnyM
     * @param row Row to be set.
     * @param vector row vector (must have the same number of columns
     * as the instance).
-    * @throws org.apache.commons.math.exception.OutOfRangeException if
+    * @throws org.apache.commons.math3.exception.OutOfRangeException if
     * the specified row index is invalid.
     * @throws MatrixDimensionMismatchException
     * if the vector dimension does not match one instance row.
@@ -307,7 +307,7 @@ public interface RealMatrix extends AnyM
     *
     * @param column Column to be fetched.
     * @return a column vector.
-    * @throws org.apache.commons.math.exception.OutOfRangeException if
+    * @throws org.apache.commons.math3.exception.OutOfRangeException if
     * the specified column index is invalid
     */
    RealVector getColumnVector(int column);
@@ -319,7 +319,7 @@ public interface RealMatrix extends AnyM
     * @param column Column to be set.
     * @param vector column vector (must have the same number of rows as
     * the instance).
     * @throws org.apache.commons.math.exception.OutOfRangeException if the
     * specified column index is invalid.
     * @throws MatrixDimensionMismatchException
     * if the vector dimension does not match one instance column.
@@ -332,7 +332,7 @@ public interface RealMatrix extends AnyM
      *
      * @param row Row to be fetched.
      * @return the array of entries in the row.
      * @throws org.apache.commons.math.exception.OutOfRangeException if the
      * specified row index is not valid.
      */
     double[] getRow(int row);
@@ -344,7 +344,7 @@ public interface RealMatrix extends AnyM
      * @param row Row to be set.
      * @param array Row matrix (must have the same number of columns as
      * the instance)
      * @throws org.apache.commons.math.exception.OutOfRangeException if the
      * specified row index is invalid.
      * @throws MatrixDimensionMismatchException
      * if the array size does not match one instance row.
@@ -357,7 +357,7 @@ public interface RealMatrix extends AnyM
      *
      * @param column Column to be fetched.
      * @return the array of entries in the column.
      * @throws org.apache.commons.math.exception.OutOfRangeException if the
      * specified column index is not valid.
      */
     double[] getColumn(int column);
@@ -369,7 +369,7 @@ public interface RealMatrix extends AnyM
      * @param column Column to be set.
      * @param array Column array (must have the same number of rows as
      * the instance).
      * @throws org.apache.commons.math.exception.OutOfRangeException if the
      * specified column index is invalid.
      * @throws MatrixDimensionMismatchException
      * if the array size does not match one instance column.
@@ -383,7 +383,7 @@ public interface RealMatrix extends AnyM
      * @param row Row location of entry to be fetched.
      * @param column Column location of entry to be fetched.
      * @return the matrix entry at {@code (row, column)}.
      * @throws org.apache.commons.math.exception.OutOfRangeException if the
      * row or column index is not valid.
      */
     double getEntry(int row, int column);
@@ -395,7 +395,7 @@ public interface RealMatrix extends AnyM
      * @param row Row location of entry to be set.
      * @param column Column location of entry to be set.
      * @param value matrix entry to be set.
-     * @throws org.apache.commons.math.exception.OutOfRangeException if
+     * @throws org.apache.commons.math3.exception.OutOfRangeException if
      * the row or column index is not valid
      * @since 2.0
      */
@@ -408,7 +408,7 @@ public interface RealMatrix extends AnyM
      * @param row Row location of entry to be set.
      * @param column Column location of entry to be set.
      * @param increment value to add to the matrix entry.
-     * @throws org.apache.commons.math.exception.OutOfRangeException if
+     * @throws org.apache.commons.math3.exception.OutOfRangeException if
      * the row or column index is not valid.
      * @since 2.0
      */
@@ -421,7 +421,7 @@ public interface RealMatrix extends AnyM
      * @param row Row location of entry to be set.
      * @param column Column location of entry to be set.
      * @param factor Multiplication factor for the matrix entry.
-     * @throws org.apache.commons.math.exception.OutOfRangeException if
+     * @throws org.apache.commons.math3.exception.OutOfRangeException if
      * the row or column index is not valid.
      * @since 2.0
      */
@@ -534,7 +534,7 @@ public interface RealMatrix extends AnyM
      * @param endRow Final row index (inclusive)
      * @param startColumn Initial column index
      * @param endColumn Final column index
-     * @throws org.apache.commons.math.exception.OutOfRangeException if
+     * @throws org.apache.commons.math3.exception.OutOfRangeException if
      * the indices are not valid.
      * @see #walkInRowOrder(RealMatrixChangingVisitor)
      * @see #walkInRowOrder(RealMatrixPreservingVisitor)
@@ -563,7 +563,7 @@ public interface RealMatrix extends AnyM
      * @param endRow Final row index (inclusive)
      * @param startColumn Initial column index
      * @param endColumn Final column index
-     * @throws org.apache.commons.math.exception.OutOfRangeException if
+     * @throws org.apache.commons.math3.exception.OutOfRangeException if
      * the indices are not valid.
      * @see #walkInRowOrder(RealMatrixChangingVisitor)
      * @see #walkInRowOrder(RealMatrixPreservingVisitor)
@@ -636,7 +636,7 @@ public interface RealMatrix extends AnyM
      * @param endRow Final row index (inclusive)
      * @param startColumn Initial column index
      * @param endColumn Final column index
-     * @throws org.apache.commons.math.exception.OutOfRangeException if
+     * @throws org.apache.commons.math3.exception.OutOfRangeException if
      * the indices are not valid.
      * @see #walkInRowOrder(RealMatrixChangingVisitor)
      * @see #walkInRowOrder(RealMatrixPreservingVisitor)
@@ -665,7 +665,7 @@ public interface RealMatrix extends AnyM
      * @param endRow Final row index (inclusive)
      * @param startColumn Initial column index
      * @param endColumn Final column index
-     * @throws org.apache.commons.math.exception.OutOfRangeException if
+     * @throws org.apache.commons.math3.exception.OutOfRangeException if
      * the indices are not valid.
      * @see #walkInRowOrder(RealMatrixChangingVisitor)
      * @see #walkInRowOrder(RealMatrixPreservingVisitor)
@@ -735,7 +735,7 @@ public interface RealMatrix extends AnyM
      * @param endRow Final row index (inclusive)
      * @param startColumn Initial column index
      * @param endColumn Final column index (inclusive)
-     * @throws org.apache.commons.math.exception.OutOfRangeException if
+     * @throws org.apache.commons.math3.exception.OutOfRangeException if
      * the indices are not valid.
      * @see #walkInRowOrder(RealMatrixChangingVisitor)
      * @see #walkInRowOrder(RealMatrixPreservingVisitor)
@@ -763,7 +763,7 @@ public interface RealMatrix extends AnyM
      * @param endRow Final row index (inclusive)
      * @param startColumn Initial column index
      * @param endColumn Final column index (inclusive)
      * @throws org.apache.commons.math.exception.OutOfRangeException if the
      * indices are not valid.
      * @see #walkInRowOrder(RealMatrixChangingVisitor)
      * @see #walkInRowOrder(RealMatrixPreservingVisitor)
@@ -175,7 +175,7 @@ public interface RealMatrix extends AnyM
     * @param destination The arrays where the submatrix data should be copied
     * (if larger than rows/columns counts, only the upper-left part will be used)
-    * @throws org.apache.commons.math.exception.OutOfRangeException if the
+    * @throws org.apache.commons.math3.exception.OutOfRangeException if the
     * indices are not valid.
     * @exception IllegalArgumentException if the destination array is too small
@@ -189,7 +189,7 @@ public interface RealMatrix extends AnyM
      * @param destination The arrays where the submatrix data should be copied
      * (if larger than rows/columns counts, only the upper-left part will be used)
-     * @throws org.apache.commons.math.exception.OutOfRangeException if the
+     * @throws org.apache.commons.math3.exception.OutOfRangeException if the
      * indices are not valid.
      * @exception IllegalArgumentException if the destination array is too small
@@ -244,7 +244,7 @@ public interface RealMatrix extends AnyM
     * @param matrix Row matrix (must have one row and the same number of
     * columns as the instance).
-    * @throws org.apache.commons.math.exception.OutOfRangeException if the
+    * @throws org.apache.commons.math3.exception.OutOfRangeException if the
     * specified row index is invalid.
     * @throws MatrixDimensionMismatchException
@@ -319,7 +319,7 @@ public interface RealMatrix extends AnyM
     * @param vector column vector (must have the same number of rows as
     * the instance).
-    * @throws org.apache.commons.math.exception.OutOfRangeException if the
+    * @throws org.apache.commons.math3.exception.OutOfRangeException if the
     * specified column index is invalid.
     * @throws MatrixDimensionMismatchException
@@ -332,7 +332,7 @@ public interface RealMatrix extends AnyM
      * @param row Row to be fetched.
      * @return the array of entries in the row.
-     * @throws org.apache.commons.math.exception.OutOfRangeException if the
+     * @throws org.apache.commons.math3.exception.OutOfRangeException if the
      * specified row index is not valid.
      */
@@ -344,7 +344,7 @@ public interface RealMatrix extends AnyM
      * @param array Row matrix (must have the same number of columns as
      * the instance)
-     * @throws org.apache.commons.math.exception.OutOfRangeException if the
+     * @throws org.apache.commons.math3.exception.OutOfRangeException if the
      * specified row index is invalid.
      * @throws MatrixDimensionMismatchException
@@ -357,7 +357,7 @@ public interface RealMatrix extends AnyM
      * @param column Column to be fetched.
      * @return the array of entries in the column.
-     * @throws org.apache.commons.math.exception.OutOfRangeException if the
+     * @throws org.apache.commons.math3.exception.OutOfRangeException if the
      * specified column index is not valid.
      */
@@ -369,7 +369,7 @@ public interface RealMatrix extends AnyM
      * @param array Column array (must have the same number of rows as
      * the instance).
-     * @throws org.apache.commons.math.exception.OutOfRangeException if the
+     * @throws org.apache.commons.math3.exception.OutOfRangeException if the
      * specified column index is invalid.
      * @throws MatrixDimensionMismatchException
@@ -383,7 +383,7 @@ public interface RealMatrix extends AnyM
      * @param column Column location of entry to be fetched.
      * @return the matrix entry at {@code (row, column)}.
-     * @throws org.apache.commons.math.exception.OutOfRangeException if the
+     * @throws org.apache.commons.math3.exception.OutOfRangeException if the
      * row or column index is not valid.
      */
@@ -763,7 +763,7 @@ public interface RealMatrix extends AnyM
      * @param startColumn Initial column index
      * @param endColumn Final column index (inclusive)
-     * @throws org.apache.commons.math.exception.OutOfRangeException if the
+     * @throws org.apache.commons.math3.exception.OutOfRangeException if the
      * indices are not valid.
      * @see #walkInRowOrder(RealMatrixChangingVisitor)

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RealMatrixChangingVisitor.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/RealMatrixChangingVisitor.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================